@@ -3,7 +3,7 @@
 #'
 #'   Utilities for text output, etc
 #'
-#'   $Revision: 1.10 $ $Date: 2021/08/26 10:24:47 $
+#'   $Revision: 1.14 $ $Date: 2023/05/07 09:52:27 $
 #'
 
 # text magic
@@ -225,11 +225,22 @@ ordinalsuffix <- function(k) {
   return(ending)
 }
 
-articlebeforenumber <- function(k) {
-  k <- abs(k)
-  if(k == 11 || k == 18) return("an")
+articlebeforenumber <- function(k, teenhundreds=FALSE) {
+  if(k < 0) return("a")  
+  k <- floor(k)
+  if(k == 0) return("a")
+  ## leading digit
   leading <- floor(k/10^floor(log10(k)))
   if(leading == 8) return("an")
+  ## leading digits in front of power of 1000
+  kilo <- floor(k/10^(3*floor(log10(k)/3)))
+  if(kilo == 11 || kilo == 18) return("an")
+  ## 
+  if(teenhundreds) {
+    hundreds <- floor(k/100)
+    if(hundreds == 11 || hundreds == 18)
+      return("an")
+  }
   return("a")
 }
 
@@ -290,6 +301,8 @@ sensiblevarname <- function(guess, fallback, maxlen=12) {
 }
 
 ## deparse() can sometimes be equivalent to dumping the whole object
+## Use this for creating data name for main title, error message etc.
+## It may truncate the information.
 short.deparse <- function(x, maxlen=60) {
   deparse(x,
           nlines=1,
@@ -298,8 +311,9 @@ short.deparse <- function(x, maxlen=60) {
 }
 
 ## deparse() can produce multiple lines of text
+## Use this for expressions that must be converted to a single string
 flat.deparse <- function(x) {
-  y <- paste(deparse(x), collapse=" ")
+  y <- paste(deparse(x), collapse=" ") 
   y <- gsub("\n", " ", y)
   y <- gsub(" ", "", y)
   return(y)
